import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:kmobile/src/preferences/color_dialog.dart';
import 'package:kmobile/src/preferences/language_dialog.dart';
import 'package:kmobile/src/preferences/preferences_provider.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';

class Preference extends StatelessWidget {
  const Preference({super.key});

  @override
  Widget build(BuildContext context) {
    PreferencesProvider preferencesProvider =
        Provider.of<PreferencesProvider>(context);
    return Scaffold(
      backgroundColor: Theme.of(context).colorScheme.background,
      appBar: AppBar(
        title: Text(AppLocalizations.of(context)!.preferences),
      ),
      body: ListView(
        children: [
          ListTile(
            title: Text(AppLocalizations.of(context)!.dark_theme),
            trailing: Switch(
                value: preferencesProvider.themeMode == ThemeMode.dark,
                onChanged: (value) {
                  preferencesProvider.themeMode =
                      value ? ThemeMode.dark : ThemeMode.light;
                }),
          ),
          const Divider(height: 0),
          ListTile(
            title: Text(AppLocalizations.of(context)!.color_theme),
            onTap: () => _changeCurrentTheme(context),
          ),
          const Divider(height: 0),
          ListTile(
            title: Text(AppLocalizations.of(context)!.language),
            onTap: () => _changeCurrentLocale(context),
          )
        ],
      ),
    );
  }

  Future<void> _changeCurrentTheme(BuildContext context) async {
    Map<ThemeMode, ColorScheme> selectedColorScheme = await showDialog(
      context: context,
      builder: (BuildContext context) {
        return const ColorDialog();
      },
    );
    if (context.mounted) {
      PreferencesProvider provider =
          Provider.of<PreferencesProvider>(context, listen: false);
      provider.colorScheme = selectedColorScheme;
    }
  }

  Future<void> _changeCurrentLocale(BuildContext context) async {
    Locale selectedLocale = await showDialog(
      context: context,
      builder: (BuildContext context) {
        return const LanguageDialog();
      },
    );
    if (context.mounted) {
      PreferencesProvider provider =
          Provider.of<PreferencesProvider>(context, listen: false);
      provider.locale = selectedLocale;
    }
  }
}
